From: Yinghai Lu <yhlu.kernel@gmail.com>
To: Len Brown <lenb@kernel.org>
Cc: Ricardo Jorge da Fonseca Marques Ferreira <storm@sys49152.net>,
Linux Kernel Mailing List <linux-kernel@vger.kernel.org>,
linux-acpi@vger.kernel.org,
Yannick Roehlly <yannick.roehlly@free.fr>,
Jesse Barnes <jesse.barnes@intel.com>,
Ivan Kokshaysky <ink@jurassic.park.msu.ru>,
Ingo Molnar <mingo@elte.hu>,
x86@kernel.org, Linus Torvalds <torvalds@linux-foundation.org>
Subject: Re: Regression in ACPI in 2.6.31-rc5
Date: Mon, 5 Oct 2009 21:38:40 -0700 [thread overview]
Message-ID: <86802c440910052138i211dce8apd50cc3558b24de44@mail.gmail.com> (raw)
In-Reply-To: <alpine.LFD.2.00.0910052312140.309@localhost.localdomain>
Len Brown wrote:
> From: Len Brown <len.brown@intel.com>
> Subject: [PATCH] Revert "x86/pci: remove rounding quirk from e820_setup_gap()"
>
> This reverts commit 5d423ccd7ba4285f1084e91b26805e1d0ae978ed.
>
> because it caused multiple regressions in 2.6.31-rc1
>
> http://bugzilla.kernel.org/show_bug.cgi?id=13940
>
> Signed-off-by: Len Brown <len.brown@intel.com>
> ---
>
> Yinghai,
> is there a reason we should not revert the offending patch, per below?
that patch is introduced fix another bug to get enough resource.
and that patch looks like reveal some bug in ACPI (?) because when
apci subsystem is enabled,
some BARs of some pci devices get cleared somehow.
actually there is patch that could workaround the problem too
---
arch/x86/kernel/e820.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
Index: linux-2.6/arch/x86/kernel/e820.c
===================================================================
--- linux-2.6.orig/arch/x86/kernel/e820.c
+++ linux-2.6/arch/x86/kernel/e820.c
@@ -1378,8 +1378,8 @@ static unsigned long ram_alignment(resou
if (mb < 16)
return 1024*1024;
- /* To 32MB for anything above that */
- return 32*1024*1024;
+ /* To 64MB for anything above that */
+ return 64*1024*1024;
}
#define MAX_RESOURCE_SIZE ((resource_size_t)-1)
but Linus wants to know why those BARs get cleared, and who is using
that extra 32M.
It seems some guys request acpidump from the reporter, and not sure
what is the result from their checking.
or need the reporter to boot with acpi.debug_layer=0x400000
acpi.debug_level=0x04000807
to pull out more result?
YH
next prev parent reply other threads:[~2009-10-06 4:39 UTC|newest]
Thread overview: 17+ messages / expand[flat|nested] mbox.gz Atom feed top
2009-08-07 22:33 Ricardo Jorge da Fonseca Marques Ferreira
2009-08-13 3:53 ` Len Brown
2009-08-16 3:00 ` Ricardo Jorge da Fonseca Marques Ferreira
2009-10-06 3:17 ` Len Brown
2009-10-06 4:38 ` Yinghai Lu [this message]
[not found] ` <4ACAC8F1.1050706@kernel.org>
2009-10-11 21:17 ` [PATCH] pci: increase alignment to make more space for hidden code Yinghai Lu
2009-10-12 16:59 ` Bjorn Helgaas
2009-10-12 17:19 ` Ingo Molnar
2009-10-12 18:43 ` Yinghai Lu
2009-10-12 18:59 ` Yinghai Lu
2009-10-12 19:22 ` Ingo Molnar
2009-10-12 19:44 ` Yinghai Lu
2009-10-13 6:08 ` Bjorn Helgaas
2009-10-13 6:49 ` Ingo Molnar
2009-10-13 15:15 ` Bjorn Helgaas
2009-10-13 19:05 ` Ricardo Jorge da Fonseca Marques Ferreira
2009-08-14 19:36 Regression in ACPI in 2.6.31-rc5 Ricardo Jorge da Fonseca Marques Ferreira
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=86802c440910052138i211dce8apd50cc3558b24de44@mail.gmail.com \
--to=yhlu.kernel@gmail.com \
--cc=ink@jurassic.park.msu.ru \
--cc=jesse.barnes@intel.com \
--cc=lenb@kernel.org \
--cc=linux-acpi@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=mingo@elte.hu \
--cc=storm@sys49152.net \
--cc=torvalds@linux-foundation.org \
--cc=x86@kernel.org \
--cc=yannick.roehlly@free.fr \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®